@@ -14,6 +14,7 @@ from abc import ABCMeta
 from abc import abstractmethod
 from abc import abstractproperty
 from typing import Any
+from typing import AnyStr
 from typing import IO
 from typing import Mapping
 from typing import Optional
@@ -52,7 +53,7 @@ class BaseSession(object):
     @abstractmethod
     def post(
         self, url     , headers                   ,
-        data                             , timeout       ,
+        data                                         , timeout       ,
         params                                         ,
     )            :
         pass
@@ -68,15 +69,15 @@ class BaseSession(object):
     @abstractmethod
     def patch(
         self, url     , headers                   ,
-        data               , timeout       ,
+        data                             , timeout       ,
         params                                         ,
     )            :
         pass
 
     @abstractmethod
     def put(
-        self, url     , headers                   , data         ,
-        timeout       ,
+        self, url     , headers                   ,
+        data                            , timeout       ,
     )            :
         pass
 
@@ -160,7 +161,7 @@ if not BUILD_GCLOUD_REST:
         def post(  # type: ignore[override]
             self, url     ,
             headers                   ,
-            data                              = None,
+            data                                          = None,
             timeout          = 10,
             params                                          = None,
         )                          :
@@ -192,8 +193,8 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         def patch(  # type: ignore[override]
-            self, url     ,
-            headers                   , data                = None,
+            self, url     , headers                   ,
+            data                              = None,
             timeout          = 10,
             params                                          = None,
         )                          :
@@ -206,7 +207,7 @@ if not BUILD_GCLOUD_REST:
 
         def put(  # type: ignore[override]
             self, url     ,
-            headers                   , data         ,
+            headers                   , data                            ,
             timeout          = 10,
         )                          :
             resp = self.session.put(
@@ -268,7 +269,7 @@ if BUILD_GCLOUD_REST:
         # analysis.
         def post(
             self, url     , headers                   ,
-            data                              = None,
+            data                                          = None,
             timeout        = 10,
             params                                          = None,
         )            :
@@ -296,7 +297,7 @@ if BUILD_GCLOUD_REST:
 
         def patch(
             self, url     , headers                   ,
-            data                = None, timeout        = 10,
+            data                              = None, timeout        = 10,
             params                                          = None,
         )            :
             with self.google_api_lock:
@@ -308,8 +309,8 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def put(
-            self, url     , headers                   , data         ,
-            timeout        = 10,
+            self, url     , headers                   ,
+            data                            , timeout        = 10,
         )            :
             with self.google_api_lock:
                 resp = self.session.put(
